@@ -37,7 +37,7 @@ void gevlik(double *data, int *n, double *par, double *dns)
   double *dvec, eps;
 
   dvec = (double *)R_alloc(*n, sizeof(double));
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
 
 
   for(i=0;i<*n;i++)  {
@@ -67,7 +67,7 @@ void gevlikt(double *data, int *n, double *par, double *trend,
 
   loc = (double *)R_alloc(*n, sizeof(double));
   dvec = (double *)R_alloc(*n, sizeof(double));
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
 
   for(i=0;i<*n;i++) loc[i] = par[0] + trend[i] * par[3];
 
@@ -96,7 +96,7 @@ void gpdlik(double *data, int *n, double *par, double *dns)
   double *dvec, eps;
   
   dvec = (double *)R_alloc(*n, sizeof(double));
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
 
   if(par[1] <= 0) {
      *dns = R_NegInf;
@@ -133,7 +133,7 @@ void gpdlikt(double *data, int *n, double *par, double *trend,
   
   loc = (double *)R_alloc(*n, sizeof(double));
   dvec = (double *)R_alloc(*n, sizeof(double));
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
 
   for(i=0;i<*n;i++) loc[i] = par[0] + trend[i] * par[3];
 
@@ -172,7 +172,7 @@ void oslik(double *data, double *thresh, int *n, int *m,
 
   dvec1 = (double *)R_alloc(*n, sizeof(double));
   dvec2 = (double *)R_alloc(*m, sizeof(double));
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
 
   for(i=0;i<*n;i++)  {
     data[i] = (data[i] - par[0]) / par[1];
@@ -216,7 +216,7 @@ void oslikt(double *data, double *thresh, int *n, int *m, int *r,
   dvec1 = (double *)R_alloc(*n, sizeof(double));
   dvec2 = (double *)R_alloc(*m, sizeof(double));
   loc = (double *)R_alloc(*m, sizeof(double));
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
 
   for(i=0;i<*m;i++) loc[i] = par[0] + trend[i] * par[3];  
 
@@ -262,7 +262,7 @@ void pplik(double *data, int *nh, double *par, double *thresh,
 
   dvec1 = (double *)R_alloc(*nh, sizeof(double));
   dvec2 = (double *)R_alloc(*n, sizeof(double));
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
     
   for(i=0;i<*nh;i++) {
     data[i] = (data[i] - par[0]) / par[1];
@@ -310,7 +310,7 @@ void pplikt(double *data, int *nh, double *par, double *thresh,
   dvec2 = (double *)R_alloc(*n, sizeof(double));
   hloc = (double *)R_alloc(*nh, sizeof(double));
   loc = (double *)R_alloc(*n, sizeof(double));
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
   
   for(i=0;i<*nh;i++) {
     hloc[i] = par[0] + htrend[i] * par[3];
@@ -389,7 +389,7 @@ void dprior_prob(double *par, double *quant, double *alpha,
   int i;
   double z[3], pr[5], pd[4], eps, lj, ld;
 
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
   pr[0] = 1 ; pr[4] = 0; 
   
   for(i=0;i<3;i++) {
@@ -443,7 +443,7 @@ void dprior_quant(double *par, double *prob, double *shape,
   int i;
   double z[3], quant[4], qd[4], eps, lj, ld;
 
-  eps = R_pow(DOUBLE_EPS, 0.3);
+  eps = R_pow(DBL_EPSILON, 0.3);
   quant[0] = 0; 
   
   for(i=0;i<3;i++) {
@@ -529,13 +529,26 @@ SEXP gibbs(SEXP n, SEXP np, SEXP thin,
         else REAL(current)[k] = prow[k];
       }
       defineVar(install("x"), current, rho);
-      dpst_lower = eval(f, rho);
+      dpst_lower = PROTECT(eval(f, rho));
+
+      if (TYPEOF(dpst_lower) != REALSXP)
+	error("non-numeric result");
+
       REAL(current)[j] = prop;
+
       defineVar(install("x"), current, rho);
-      dpst_upper = eval(f, rho);
+      dpst_upper = PROTECT(eval(f, rho));
+
+      if (TYPEOF(dpst_upper) != REALSXP)
+	error("non-numeric result");
+
       post_ratio = exp(REAL(dpst_upper)[0] - REAL(dpst_lower)[0]);
+
       if(!R_FINITE(REAL(dpst_upper)[0]))
         REAL(nex)[j] = REAL(nex)[j] + 1;
+
+      UNPROTECT(2);
+
       acc_prob = fmin2(1, prop_ratio * post_ratio);
       if(R_IsNaN(acc_prob)) {
         acc_prob = 0;
@@ -559,3 +572,6 @@ SEXP gibbs(SEXP n, SEXP np, SEXP thin,
   UNPROTECT(7);
   return(ans);
 }
+
+
+
